$ErrorActionPreference = 'Stop'
$toolsDir = "$(Split-Path -parent $MyInvocation.MyCommand.Definition)"
. $toolsDir\helpers.ps1

# 32/64bit installer
#$url = 'http://provisioning.fusionts.corp/win/apps/crowdstrike/WindowsSensor.exe'
$url = Join-Path $toolsDir 'WindowsSensor_v6.12.12601.exe'

$pp = Get-PackageParameters
$cs_CID = $pp['CID'] #customer ID (CID)
$cs_ProvToken = $pp['ProvToken'] #Installation Token
$cs_ProvWaitTime = $pp['ProvWaitTime']
$cs_ProvNoWait = $pp['ProvNoWait']
$cs_GroupingTags = $pp['GroupingTags'] #Assigning Tags
$cs_MaintenanceToken = $pp['MaintenanceToken'] #Maintenance Token is required if you planned to upgrade package to lastest version

if ($cs_CID) {
  $CID = "CID=$cs_CID"
  Write-Output "PackageParameter CID: $cs_CID"
}
######
if ($cs_ProvToken) {
  $ProvToken = "ProvToken=$cs_ProvToken"
  Write-Output "PackageParameter ProvToken: $cs_ProvToken"
}
######
if ($cs_ProvWaitTime) {
  $ProvWaitTime = "ProvWaitTime=$cs_ProvWaitTime"
  Write-Output "PackageParameter ProvWaitTime: $cs_ProvWaitTime"
}
######
if (!$cs_ProvNoWait) {
  $ProvNoWait = 'ProvNoWait=1'
} else {
  Write-Output "PackageParameter ProvNoWait: $cs_ProvNoWait"
  $ProvNoWait = "ProvNoWait=$cs_ProvNoWait"
}
######
if ($cs_GroupingTags) {
  Write-Output "PackageParameter GroupingTags: $cs_GroupingTags"
  $GroupingTags = "GROUPING_TAGS='$cs_GroupingTags'"
}
######
if ($cs_MaintenanceToken) {
  Write-Output "PackageParameter Maintenance Token: $cs_MaintenanceToken"
  $MaintenanceToken = "MAINTENANCE_TOKEN='$cs_MaintenanceToken'"
}

$packageArgs = @{
	packageName   = $env:ChocolateyPackageName
	softwareName  = 'CrowdStrike Windows Sensor*'
  version       = $env:ChocolateyPackageVersion
	unzipLocation = $toolsDir
	installerType = 'exe'
  file          = $url
  #file64        = $url64
	checksum      = '60a210c007fdc4c98c339ac56c947df1eadcf0ad610891061eaa4de90e5180ed'
	checksumType  = 'sha256' #default is md5, can also be sha1, sha256 or sha512
	#checksum64    = ''
	#checksumType64= 'sha512' #default is checksumType
	silentArgs = "$MaintenanceToken /quiet /install /norestart $CID $ProvToken $ProvNoWait $ProvWaitTime $GroupingTags"
	#Exit codes for ms http://msdn.microsoft.com/en-us/library/aa368542(VS.85).aspx
  validExitCodes = @(
    0, # success
    3010, # success, restart required
    2147781575, # pending restart required
    2147205120  # pending restart required for setup update
  )
}
if ($cs_CID) {
  Install-ChocolateyPackage @packageArgs
}else {
  Write-Error "This package 'crowdstrike-falcon-sensor' requires additional parameter of CrowdStrike Customer ID: /CID:xxxxxxxxxxxxxxxxxxxxxx-xx"
}